@@ -21,11 +21,19 @@ asin2ir <- function(x, time = NULL, value = "mean", warn = TRUE) {
   if (any(sel0, na.rm = TRUE)) {
     if (warn)
       warning("Too small value for ",
-              if (length(x) > 1) "at least one ",
-              if (value == "mean") "transformed proportion using Freeman-Tukey double arcsine transformation.\n  Rate set to 0.",
-              if (value == "lower") "lower confidence limit using Freeman-Tukey double arcsine transformation.\n  Lower confidence limit set to 0.",
-              if (value == "upper") "upper confidence limit using Freeman-Tukey double arcsine transformation.\n  Upper confidence limit set to 0.",
-              sep = "")
+              if (length(x) > 1)
+                "at least one ",
+              if (value == "mean")
+                paste0("transformed proportion using Freeman-Tukey double ",
+                       "arcsine transformation.\n  Rate set to 0."),
+              if (value == "lower")
+                paste0("lower confidence limit using Freeman-Tukey double ",
+                       "arcsine transformation.",
+                       "\n  Lower confidence limit set to 0."),
+              if (value == "upper")
+                paste0("upper confidence limit using Freeman-Tukey double ",
+                       "arcsine transformation.",
+                       "\n  Upper confidence limit set to 0."))
   }
   
   
