@@ -3,9 +3,7 @@ setunit <- function(x) {
   
   if (is.character(x)) {
     if (length(x) != 1)
-      stop(paste("Argument '", xname,
-                 "' must be a character string.",
-                 sep = ""))
+      stop("Argument '", xname, "' must be a character string.")
     ##
     plotunit <- ""
     if (length(grep("cm", tolower(x))) == 1)
@@ -16,34 +14,26 @@ setunit <- function(x) {
       plotunit <- "mm"
     ##
     if (plotunit == "")
-      stop(paste("Argument '", xname,
-                 "' must contain 'cm', 'inch', or 'mm'.",
-                 sep = ""))
+      stop("Argument '", xname, "' must contain 'cm', 'inch', or 'mm'.")
     ##
     if (plotunit == "cm") {
       plotval <- substring(x, 1, nchar(x) - 2)
       if (length(plotval) == 0 | is.na(as.numeric(plotval)))
-        stop(paste("Argument '", xname,
-                   "' must contain at least one number.",
-                   sep = ""))
+        stop("Argument '", xname, "' must contain at least one number.")
       ##
       res <- grid::unit(as.numeric(plotval), "cm")
     }
     else if (plotunit == "inch") {
       plotval <- substring(x, 1, nchar(x) - 4)
       if (length(plotval) == 0 | is.na(as.numeric(plotval)))
-        stop(paste("Argument '", xname,
-                   "' must contain at least one number.",
-                   sep = ""))
+        stop("Argument '", xname, "' must contain at least one number.")
       ##
       res <- grid::unit(as.numeric(plotval), "inch")
     }
     else if (plotunit == "mm") {
       plotval <- substring(x, 1, nchar(x) - 2)
       if (length(plotval) == 0 | is.na(as.numeric(plotval)))
-        stop(paste("Argument '", xname,
-                   "' must contain at least one number.",
-                   sep = ""))
+        stop("Argument '", xname, "' must contain at least one number.")
       ##
       res <- grid::unit(as.numeric(plotval), "mm")
     }
